@@ -8,6 +8,7 @@ from optparse import OptionParser
 from peewee import *
 from peewee import print_
 from peewee import __version__ as peewee_version
+from playhouse.cockroachdb import CockroachDatabase
 from playhouse.reflection import *
 
 
@@ -28,6 +29,7 @@ class UnknownField(object):
 """
 
 DATABASE_ALIASES = {
+    CockroachDatabase: ['cockroach', 'cockroachdb', 'crdb'],
     MySQLDatabase: ['mysql', 'mysqldb'],
     PostgresqlDatabase: ['postgres', 'postgresql'],
     SqliteDatabase: ['sqlite', 'sqlite3'],
@@ -166,8 +168,8 @@ def get_option_parser():
     ao('-P', '--password', dest='password', action='store_true')
     engines = sorted(DATABASE_MAP)
     ao('-e', '--engine', dest='engine', default='postgresql', choices=engines,
-       help=('Database type, e.g. sqlite, mysql or postgresql. Default '
-             'is "postgresql".'))
+       help=('Database type, e.g. sqlite, mysql, postgresql or cockroachdb. '
+             'Default is "postgresql".'))
     ao('-s', '--schema', dest='schema')
     ao('-t', '--tables', dest='tables',
        help=('Only generate the specified tables. Multiple table names should '
